@@ -13,12 +13,24 @@ type metadata struct {
 	AMIs map[string]struct {
 		HVM string `json:"hvm"`
 	} `json:"amis"`
+	Azure struct {
+		Image string `json:"image"`
+		URL   string `json:"url"`
+	}
+	GCP struct {
+		Image string `json:"image"`
+		URL   string `json:"url"`
+	}
 	BaseURI string `json:"baseURI"`
 	Images  struct {
 		QEMU struct {
 			Path   string `json:"path"`
 			SHA256 string `json:"sha256"`
 		} `json:"qemu"`
+		OpenStack struct {
+			Path   string `json:"path"`
+			SHA256 string `json:"sha256"`
+		} `json:"openstack"`
 	} `json:"images"`
 	OSTreeVersion string `json:"ostree-version"`
 }
